@@ -72,6 +72,7 @@
 #include "importitemdialog.h"
 #include "addressprovider.h"
 #include "addressselectordialog.h"
+#include "format.h"
 
 #define NO_TAX   0
 #define RED_TAX  1
@@ -550,7 +551,7 @@ PositionViewWidget *KraftView::createPositionViewWidget( DocPositionBase *dp, in
     }
   }
 
-  w->setDocPosition( dp, getDocument()->locale() );
+  w->setDocPosition(dp);
   w->setOrdNumber( pos+1 );
   w->slotSetTax( dp->taxType() );
   return w;
@@ -582,7 +583,7 @@ void KraftView::refreshPostCard()
 
   if ( mAssistant->postCard() ) {
     QDate d = m_headerEdit->m_dateEdit->date();
-    const QString dStr = getDocument()->locale()->toString( d, getDocument()->locale()->dateFormat(QLocale::ShortFormat));
+    const QString dStr = Format::toDateString( d, KraftSettings::self()->dateFormat() );
 
     mAssistant->postCard()->setHeaderData( m_headerEdit->m_cbType->currentText(),
                                            dStr, m_headerEdit->m_postAddressEdit->toPlainText(),
@@ -949,6 +950,8 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
   dia.reset(new InsertTemplDialog( this ));
   dia->setCatalogChapters( kat->getKatalogChapters() );
 
+  int tmplId = 0;
+
   if ( newTemplate ) {
       // New templates may only go to the standard template catalog, FIXME
   } else {
@@ -1009,6 +1012,7 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
 
               flos->setManualPrice( dp->unitPrice() );
               flos->save();
+              tmplId = flos->getTemplID();
 
               // reload the entire katalog
               Katalog *defaultKat = KatalogMan::self()->defaultTemplateCatalog();
@@ -1016,6 +1020,8 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
                   defaultKat->load();
                   KatalogMan::self()->notifyKatalogChange( defaultKat , dbID() );
               }
+          } else {
+              tmplId = static_cast<FloskelTemplate*>(tmpl)->getTemplID();
           }
       } else if ( kat->type() == MaterialCatalog ) {
           if ( newTemplate ) {
@@ -1031,6 +1037,10 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
       return;
   }
 
+  if (tmplId > 0) {
+      kat->recordUsage(tmplId);
+  }
+
   PositionViewWidget *widget = createPositionViewWidget( dp, newpos );
   widget->slotModified();
   widget->slotAllowIndividualTax( currentTaxSetting() == DocPositionBase::TaxIndividual );
@@ -1085,6 +1095,8 @@ void KraftView::slotAddExtraPosition()
   DocPosition *dp = new DocPosition( DocPosition::ExtraDiscount );
   dp->setPositionNumber( newpos+1 );
   dp->setText( i18n( "Discount" ) );
+  Einheit e = UnitManager::self()->getPauschUnit();
+  dp->setUnit(e);
   if( currentTaxSetting() == DocPositionBase::TaxIndividual ) {
     dp->setTaxType( DocPositionBase::TaxFull );
   } else {
@@ -1104,10 +1116,7 @@ void KraftView::slotAddExtraPosition()
 DocPositionList KraftView::currentPositionList()
 {
     DocPositionList list;
-    if( m_doc ) {
-        list.setLocale( m_doc->locale() );
-    }
-    PositionViewWidget *widget;
+    PositionViewWidget *widget = nullptr;
     int cnt = 1;
 
     PositionViewWidgetListIterator outerIt( mPositionWidgetList );
@@ -1190,8 +1199,8 @@ DocPositionList KraftView::currentPositionList()
 
             // replace some tags in the text
 
-            replaceMap["%DISCOUNT"]     = getDocument()->locale()->toString( discount );
-            replaceMap["%ABS_DISCOUNT"] = getDocument()->locale()->toString( qAbs( discount ) );
+            replaceMap["%DISCOUNT"]     = DefaultProvider().self()->locale()->toString( discount );
+            replaceMap["%ABS_DISCOUNT"] = DefaultProvider().self()->locale()->toString( qAbs( discount ) );
 
           } else {
             /* Type is ordinary position */
@@ -1342,6 +1351,9 @@ void KraftView::done( int r )
     // remember the sizes of the docassistant splitter if visible.
     mAssistant->saveSplitterSizes();
     KraftSettings::self()->setDocViewSplitter(mCSplit->sizes());
+    const QByteArray geo = saveGeometry().toBase64();
+    KraftSettings::self()->setDocEditGeometry(geo);
+
     QDialog::done( r );
 }
 
