@@ -157,8 +157,8 @@ void PortalView::fillCatalogDetails()
     const QStringList katalogNamen = KatalogMan::self()->allKatalogNames();
     QString html;
 
-    html = "<br/><h2>" + i18n("Available Catalogs") + "</h2>";
-    html += "<div><table width=\"60%\" cellpadding=\"4\" cellspacing=\"0\" border=\"0\">\n";
+    html = QStringLiteral("<br/><h2>") + i18n("Available Catalogs") + QStringLiteral("</h2>");
+    html += QStringLiteral("<div><table width=\"60%\" cellpadding=\"4\" cellspacing=\"0\" border=\"0\">\n");
 
     int cnt = 0;
     for(QStringList::ConstIterator namesIt = katalogNamen.begin();
@@ -168,15 +168,14 @@ void PortalView::fillCatalogDetails()
         html += printKatLine( katName, cnt++ );
     }
 
-    html += "</table></div>\n";
-    // qDebug() << html;
+    html += QStringLiteral("</table></div>\n");
 
     mCatalogBrowser->displayContent( html );
 }
 
 QString PortalView::printKatLine( const QString& name, int cnt ) const
 {
-    QString urlName = Qt::escape( name );
+    QString urlName = name.toHtmlEscaped();
 
     // qDebug () << "Converted Katalog name: " << urlName << endl;
     QString html;
@@ -259,8 +258,9 @@ QString PortalView::systemView( const QString& htmlMsg ) const
 
   // Note: This code is stolen from DocDigestDetailView::slotShowDocDetails
   // It should be refactored.
-  TextTemplate tmpl( tmplFile );
-  if( !tmpl.open() ) {
+  TextTemplate tmpl;
+  tmpl.setTemplateFileName(tmplFile);
+  if( !tmpl.isOk() ) {
       return QString ("");
   }
 
@@ -276,7 +276,7 @@ QString PortalView::systemView( const QString& htmlMsg ) const
   tmpl.setValue( "KRAFT_MAINTAINER", i18n("Developer and Maintainer"));
   tmpl.setValue( "KRAFT_DEVELOPER", i18n("Developer"));
   tmpl.setValue( "KRAFT_GRAPHICS", i18nc("The person who provided the logo graphics", "Logo design"));
-
+  tmpl.setValue( "KRAFT_MANUAL", i18nc("The person who provided the user manual", "User Manual"));
   // kraft infos
   tmpl.setValue("KRAFT_INTRO_DESC", i18n("Kraft helps you to handle documents like quotes and invoices in your small business."));
   tmpl.setValue( "KRAFT_WELCOME_LABEL", i18n( "Welcome to Kraft" ) );
@@ -296,7 +296,6 @@ QString PortalView::systemView( const QString& htmlMsg ) const
       QString errorMessage = i18n( "There is a initialisation error on your system. Kraft will not work that way." );
       errorMessage += htmlMsg;
       tmpl.setValue( "ERROR_TEXT", errorMessage );
-
       return tmpl.expand();
   }
 
@@ -343,7 +342,7 @@ QString PortalView::systemView( const QString& htmlMsg ) const
   // external tools
   tmpl.setValue( "EXTERNAL_TOOLS_LABEL", i18n( "External Tools" ) );
   tmpl.setValue( "RML2PDF_TOOL_LABEL", i18n( "RML to PDF conversion tool" ) );
-  QStringList trml2pdf = ReportGenerator::self()->findTrml2Pdf();
+  QStringList trml2pdf = DefaultProvider::self()->findTrml2Pdf();
 
   QString trml2pdfValue = (trml2pdf.count() ? trml2pdf.join(" ") : i18n("not found!") );
   tmpl.setValue( "RML2PDF_TOOL", trml2pdfValue );
@@ -351,6 +350,14 @@ QString PortalView::systemView( const QString& htmlMsg ) const
   tmpl.setValue( "ICONV_TOOL_LABEL", i18n( "iconv tool for text import" ) );
   tmpl.setValue( "ICONV_TOOL", DefaultProvider::self()->iconvTool() );
 
+  tmpl.setValue( "WEASYPRINT_TOOL_LABEL", i18n( "<a href=\"https://weasyprint.org/\">weasyprint</a> for PDF generation" ) );
+
+  QString wp = DefaultProvider::self()->locateBinary("weasyprint");
+  if (wp.isEmpty()) {
+      wp = i18n("not available");
+  }
+  tmpl.setValue( "WEASYPRINT_TOOL", wp);
+
   // aknowledgement
   tmpl.setValue( "ICON_ACKNOWLEDGEMENT_LABEL", i18n("Some Icons are made by") );
   tmpl.setValue( "ACKNOWLEGEMENT_LABEL", i18n( "Acknowledgements" ) );
